**To delete an origin endpoint**

The following ``delete-origin-endpoint`` command deletes the origin endpoint named ``tester2``. ::

    aws mediapackage delete-origin-endpoint \
        --id tester2

For more information, see `Deleting an Endpoint <https://docs.aws.amazon.com/mediapackage/latest/ug/endpoints-delete.html>`__ in the *AWS Elemental MediaPackage User Guide*.
